pub enum Error {
UnspecifiedQueryState,
QueryUnsupportedForTarget,
UnexpectedReplyInProgress,
UnexpectedRequestInProgress,
ReceivedSubmitWhenExpectingReplyChunk,
ReceivedReplyWhenExpectingSubmitChunk,
MoreAfterQueryComplete {
id: usize,
},
InvalidJsonInQueryKey(Error),
InvalidJsonInQueryOutput(Error),
}Expand description
An enumeration of errors that can occur in a Hipcheck plugin
Variants
UnspecifiedQueryState
An unknown error occurred, the query is in an unspecified state
QueryUnsupportedForTarget
UnexpectedReplyInProgress
The PluginEngine received a message with the unexpected status ReplyInProgress
UnexpectedRequestInProgress
The PluginEngine received a message with the unexpected status RequestInProgress
ReceivedSubmitWhenExpectingReplyChunk
The PluginEngine received a message with a request-type status when it expected a reply
ReceivedReplyWhenExpectingSubmitChunk
The PluginEngine received a message with a reply-type status when it expected a submit
MoreAfterQueryComplete
The PluginEngine received additional messages when it did not expect any
InvalidJsonInQueryKey(Error)
InvalidJsonInQueryOutput(Error)