#[repr(i32)]pub enum ConfigurationStatus {
Unspecified = 0,
None = 1,
MissingRequiredConfiguration = 2,
UnrecognizedConfiguration = 3,
InvalidConfigurationValue = 4,
}Variants
Unspecified = 0
An unknown error occured.
None = 1
No error; the operation was successful.
MissingRequiredConfiguration = 2
The user failed to provide a required configuration item.
UnrecognizedConfiguration = 3
The user provided a configuration item whose name was not recognized.
InvalidConfigurationValue = 4
The user provided a configuration item whose value is invalid.
Implementations
Sourceimpl ConfigurationStatus
impl ConfigurationStatus
Sourcepub fn from_i32(value: i32) -> Option<ConfigurationStatus>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<ConfigurationStatus>
Converts an i32 to a ConfigurationStatus, or None if value is not a valid variant.
Sourceimpl ConfigurationStatus
impl ConfigurationStatus
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.